Gladier Tools
=============
|docs|

.. |docs| image:: https://readthedocs.org/projects/gladier/badge/?version=latest
   :target: https://gladier.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/globus-gladier/gladier-tools/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/globus-gladier/gladier-tools/actions/workflows/

.. image:: https://img.shields.io/pypi/v/gladier-tools.svg
    :target: https://pypi.python.org/pypi/gladier-tools

.. image:: https://img.shields.io/pypi/wheel/gladier-tools.svg
    :target: https://pypi.python.org/pypi/gladier-tools

.. image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
    :alt: License
    :target: https://opensource.org/licenses/Apache-2.0

Gladier Tools extends the core Gladier package to include commonly needed utilities. They're
designed to easily drop into existing Gladier Client toolsets.


Installation
============

Install with the following:


.. code-block:: bash

   pip install gladier-tools

See the `Read-The-Docs <https://gladier.readthedocs.io/en/stable/tools/index.html>`_ page for a
list of available tools and how to use them.